@@ -18,8 +18,16 @@
 // https://web.archive.org/web/20201018211550/https://developer.mozilla.org/en-US/docs/Archive/Add-ons/Code_snippets/File_I_O
 
 const {classes: Cc, interfaces: Ci, utils: Cu} = Components;
-Cu.import("resource://gre/modules/Services.jsm");
-Cu.import("resource://gre/modules/FileUtils.jsm");
+const Services = globalThis.Services;
+const { AppConstants } = ChromeUtils.importESModule("resource://gre/modules/AppConstants.sys.mjs");
+const IS_ESM_READY = parseInt(AppConstants.MOZ_APP_VERSION, 10) >= 128;
+
+// We need to conditionally load some modules because they haven't been ported
+// the ES module yet. This workaround can be removed when ESR128 will be EOL.
+const { FileUtils } =
+    IS_ESM_READY
+      ? ChromeUtils.importESModule("resource://gre/modules/FileUtils.sys.mjs")
+      : Cu.import("resource://gre/modules/FileUtils.jsm");
 
 var g_ff_version;
 var g_updated = false;
@@ -263,8 +271,31 @@ function css_files_update() {
         set_firefox_version_previous(g_ff_version);
 }
 
+/**
+ * Builds a user-agent as similar to the default as possible, but with "Mobile"
+ * inserted into the platforms section.
+ *
+ * @returns {string}
+ */
+function build_user_agent() {
+    var appinfo = Services.appinfo;
+    var vendor = appinfo.vendor || "Mozilla";
+    var os = appinfo.OS || "Linux";
+    var version = get_firefox_version() + ".0";
+    var name = appinfo.name || "Firefox";
+    var arch = (appinfo.XPCOMABI && appinfo.XPCOMABI.includes("-"))
+        ? appinfo.XPCOMABI.split("-")[0]
+        : "aarch64";
+
+    return `${vendor}/5.0 (X11; ${os} ${arch}; Mobile; rv:${version}) Gecko/20100101 ${name}/${version}`;
+}
+
 function set_default_prefs() {
     log("Setting default preferences");
+
+    var user_agent = build_user_agent();
+    defaultPref('general.useragent.override', user_agent);
+
     // Do not suggest facebook, ebay, reddit etc. in the urlbar. Same as
     // Settings -> Privacy & Security -> Address Bar -> Shortcuts. As
     // side-effect, the urlbar results are not immediatelly opened once
@@ -286,6 +317,25 @@ function set_default_prefs() {
     // shows recently closed tabs. The always pinned tab takes up screen estate
     // and it's slightly annoying if you do not want to register an account.
     defaultPref('browser.tabs.firefox-view', false);
+
+    // FF >= 116 allows to use cameras via Pipewire. While it will likely still
+    // take a while until this is made the default, on most mobile devices it
+    // makes a lot of sense to enable it unconditionally, as cameras usually
+    // only work with libcamera, not via plain v4l2.
+    defaultPref('media.webrtc.camera.allow-pipewire', true);
+
+    // Make navigator.maxTouchPoints return 1 for clients to determine this is a
+    // touch device. This is the same value used by Web Developer Tools ->
+    // Responsive Design Mode -> Enable touch simulation.
+    defaultPref('dom.maxtouchpoints.testing.value', 1);
+
+    // Hide https:// in urlbar by default to save space and make more relevant
+    // parts of the urlbar visible.
+    defaultPref('browser.urlbar.trimHttps', true);
+
+    // Use the xdg-desktop-portal.file-picker by default, e.g., for a native
+    // file-picker instead of gtk-file-picker on Plasma Mobile
+    defaultPref('widget.use-xdg-desktop-portal.file-picker', 1);
 }
 
 function main() {
